@@ -1,48 +1,53 @@
 package Tags::HTML::Messages;
 
+use base qw(Tags::HTML);
 use strict;
 use warnings;
 
 use Class::Utils qw(set_params);
 use Error::Pure qw(err);
+use Scalar::Util qw(blessed);
 
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 # Constructor.
 sub new {
 	my ($class, @params) = @_;
 
 	# Create object.
-	my $self = bless {}, $class;
-
-	# 'CSS::Struct' object.
-	$self->{'css'} = undef;
-
-	# 'Tags' object.
-	$self->{'tags'} = undef;
-
-	# Process params.
-	set_params($self, @params);
-
-	# Check to 'Tags' object.
-	if (! $self->{'tags'} || ! $self->{'tags'}->isa('Tags::Output')) {
-		err "Parameter 'tags' must be a 'Tags::Output::*' class.";
-	}
-
-	# Check to 'CSS::Struct' object.
-	if ($self->{'css'} && ! $self->{'css'}->isa('CSS::Struct::Output')) {
-		err "Parameter 'css' must be a 'CSS::Struct::Output::*' class.";
-	}
+	my $self = $class->SUPER::new(@params);
 
 	# Object.
 	return $self;
 }
 
+sub _check_messages {
+	my ($self, $message_ar) = @_;
+
+	if (ref $message_ar ne 'ARRAY') {
+		err "Bad list of messages.";
+	}
+	foreach my $message (@{$message_ar}) {
+		if (! blessed($message) || ! $message->isa('Data::Message::Simple')) {
+
+			err 'Bad message data object.';
+		}
+	}
+
+	return;
+}
+
 # Process 'Tags'.
-sub process {
-	my ($self, $message_ar, $id) = @_;
+sub _process {
+	my ($self, $message_ar) = @_;
+
+	$self->_check_messages($message_ar);
 
 	my $num = 0;
+	$self->{'tags'}->put(
+		['b', 'div'],
+		['a', 'class', 'messages'],
+	);
 	if (@{$message_ar}) {
 		foreach my $message (@{$message_ar}) {
 			if ($num) {
@@ -53,23 +58,30 @@ sub process {
 			}
 			$self->{'tags'}->put(
 				['b', 'span'],
-				['a', 'id', $id],
-				['d', $message],
+				['a', 'class', $message->type],
+				['d', $message->text],
 				['e', 'span'],
 			);
+			$num++;
 		}
-		$num++;
+	} else {
+		$self->{'tags'}->put(
+			['d', 'No messages'],
+		);
 	}
+	$self->{'tags'}->put(
+		['e', 'div'],
+	);
 
 	return;
 }
 
 # Process 'CSS::Struct'.
-sub process_css {
-	my ($self, $id, $color) = @_;
+sub _process_css {
+	my ($self, $type, $color) = @_;
 
 	$self->{'css'}->put(
-		['s', '#'.$id],
+		['s', '.'.$type],
 		['d', 'color', $color],
 		['e'],
 	);
@@ -94,8 +106,8 @@ Tags::HTML::Messages - Tags helper for HTML messages.
  use Tags::HTML::Messages;
 
  my $obj = Tags::HTML::Messages->new(%params);
- $obj->process($message_ar, $id);
- $obj->process_css($id, $color);
+ $obj->process($message_ar);
+ $obj->process_css($type, $color);
 
 =head1 METHODS
 
@@ -111,50 +123,59 @@ Constructor.
 
 'CSS::Struct::Output' object for L<process_css> processing.
 
-It's required.
-
 Default value is undef.
 
 =item * C<tags>
 
 'Tags::Output' object.
 
-It's required.
-
 Default value is undef.
 
 =back
 
 =head2 C<process>
 
- $obj->process($message_ar, $id);
+ $obj->process($message_ar);
 
 Process Tags structure for output.
 
+Reference to array with message objects C<$message_ar> must be a instance of
+L<Data::Message::Simple> object.
+
 Returns undef.
 
 =head2 C<process_css>
 
- $obj->process_css($id, $color);
+ $obj->process_css($type, $color);
 
 Process CSS::Struct structure for output.
 
+Variable C<$type> is string which define message type. Possible values are info
+and error now. Types are defined in L<Data::Message::Simple>.
+
 Returns undef.
 
 =head1 ERRORS
 
  new():
-         Parameter 'css' must be a 'CSS::Struct::Output::*' class.
-         Parameter 'tags' must be a 'Tags::Output::*' class.
          From Class::Utils::set_params():
                  Unknown parameter '%s'.
+         Parameter 'css' must be a 'CSS::Struct::Output::*' class.
+         Parameter 'tags' must be a 'Tags::Output::*' class.
+
+ process():
+         Bad list of messages.
+         Bad message data object.
 
 =head1 EXAMPLE1
 
+=for comment filename=html_page_with_messages.pl
+
  use strict;
  use warnings;
 
  use CSS::Struct::Output::Indent;
+ use Data::Message::Simple;
  use Tags::HTML::Page::Begin;
  use Tags::HTML::Page::End;
  use Tags::HTML::Messages;
@@ -168,6 +189,10 @@ Returns undef.
  my $css = CSS::Struct::Output::Indent->new;
  my $begin = Tags::HTML::Page::Begin->new(
          'css' => $css,
+         'lang' => {
+                 'title' => 'Tags::HTML::Messages example',
+         },
+         'generator' => 'Tags::HTML::Messages',
          'tags' => $tags,
  );
  my $end = Tags::HTML::Page::End->new(
@@ -179,21 +204,28 @@ Returns undef.
  );
 
  # Error structure.
- my $error_messages_ar = [
-         'Error #1',
-         'Error #2',
- ];
- my $ok_messages_ar = [
-         'Ok #1',
-         'Ok #2',
+ my $message_ar = [
+         Data::Message::Simple->new(
+                 'text' => 'Error #1',
+                 'type' => 'error',
+         ),
+         Data::Message::Simple->new(
+                 'text' => 'Error #2',
+                 'type' => 'error',
+         ),
+         Data::Message::Simple->new(
+                 'text' => 'Ok #1',
+         ),
+         Data::Message::Simple->new(
+                 'text' => 'Ok #2',
+         ),
  ];
 
  # Process page.
  $messages->process_css('error', 'red');
- $messages->process_css('ok', 'green');
+ $messages->process_css('info', 'green');
  $begin->process;
- $messages->process($error_messages_ar, 'error');
- $messages->process($ok_messages_ar, 'ok');
+ $messages->process($message_ar);
  $end->process;
 
  # Print out.
@@ -201,41 +233,50 @@ Returns undef.
 
  # Output:
  # <!DOCTYPE html>
- # <html>
+ # <html lang="en">
  #   <head>
  #     <meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />
+ #     <meta name="generator" content="Tags::HTML::Messages" />
+ #     <meta name="viewport" content="width=device-width, initial-scale=1.0" />
  #     <title>
- #       Page title
+ #       Tags::HTML::Messages example
  #     </title>
  #     <style type="text/css">
- # #error {
- # 	color: red;
+ # .error {
+ #         color: red;
  # }
- # #ok {
- # 	color: green;
+ # .info {
+ #         color: green;
  # }
  # </style>
  #   </head>
  #   <body>
- #     <span id="error">
- #       Error #1
- #     </span>
- #     <span id="error">
- #       Error #2
- #     </span>
- #     <span id="ok">
- #       Ok #1
- #     </span>
- #     <span id="ok">
- #       Ok #2
- #     </span>
+ #     <div class="messages">
+ #       <span class="error">
+ #         Error #1
+ #       </span>
+ #       <br />
+ #       <span class="error">
+ #         Error #2
+ #       </span>
+ #       <br />
+ #       <span class="info">
+ #         Ok #1
+ #       </span>
+ #       <br />
+ #       <span class="info">
+ #         Ok #2
+ #       </span>
+ #     </div>
  #   </body>
  # </html>
 
 =head1 DEPENDENCIES
 
 L<Class::Utils>,
-L<Error::Pure>.
+L<Error::Pure>,
+L<Scalar::Util>,
+L<Tags::HTML>.
 
 =head1 REPOSITORY
 
@@ -249,12 +290,12 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
-© Michal Josef Špaček 2020
+© Michal Josef Špaček 2020-2023
 
 BSD 2-Clause License
 
 =head1 VERSION
 
-0.02
+0.03
 
 =cut
